@@ -10,7 +10,6 @@ import sys
 import tempfile
 import time
 import unittest
-from time import sleep
 from ctypes import cdll
 
 
@@ -20,6 +19,7 @@ from tpm2_pytss import *
 class BaseTpmSimulator(object):
     def __init__(self):
         self.tpm = None
+        self._port = None
 
     @staticmethod
     def ready(port):
@@ -28,27 +28,48 @@ class BaseTpmSimulator(object):
 
     def start(self):
         logger = logging.getLogger("DEBUG")
-        logger.debug('Setting up simulator: "{}"'.format(self.tpm))
+        logger.debug('Setting up simulator: "{}"'.format(self.exe))
 
         tpm = None
-        for _ in range(0, 10):
+        for _ in range(0, 20):
 
             random_port = random.randrange(2321, 65534)
 
-            tpm = self._start(port=random_port)
+            sim = self._start(port=random_port)
+            for _ in range(0, 10):
+                rc = sim.poll()
+                if rc is not None:
+                    logger.debug(f"Simulator {self.exe} exited with {rc}")
+                    break
+                if (
+                    sim.poll() is None
+                    and self.ready(random_port)
+                    and self.ready(random_port + 1)
+                ):
+                    tpm = sim
+                    break
+                time.sleep(0.1)
+
             if tpm:
-                # Wait to ensure that the simulator is ready for clients.
-                time.sleep(1)
-                if not self.ready(random_port):
-                    continue
-                self.tpm = tpm
+                self.tpm = sim
+                self._port = random_port
+                logger.debug(f"started {self.exe} on port {random_port}\n")
                 break
+            else:
+                sim.kill()
 
         if not tpm:
             raise SystemError("Could not start simulator")
 
     def close(self):
+        if self.tpm.poll() is not None:
+            return
         self.tpm.terminate()
+        try:
+            self.tpm.wait(timeout=1)
+        except subprocess.TimeoutExpired:
+            self.tpm.kill()
+        self.tpm.wait(timeout=10)
 
     def __str__(self):
         return self.exe
@@ -80,13 +101,7 @@ class SwtpmSimulator(BaseTpmSimulator):
         ]
 
         tpm = subprocess.Popen(cmd)
-        sleep(2)
-
-        if not tpm.poll():
-            self._port = port
-            return tpm
-
-        return None
+        return tpm
 
     @property
     def tcti_name_conf(self):
@@ -118,13 +133,7 @@ class IBMSimulator(BaseTpmSimulator):
         try:
             cmd = ["tpm_server", "-rm", "-port", "{}".format(port)]
             tpm = subprocess.Popen(cmd)
-            sleep(2)
-
-            if not tpm.poll():
-                self._port = port
-                return tpm
-
-            return None
+            return tpm
 
         finally:
             os.chdir(cwd)
@@ -191,6 +200,9 @@ class TSS2_EsapiTest(TSS2_BaseTest):
         self.tcti = None
         self.ectx = None
 
+    def skipIfAlgNotSupported(self, alg: TPM2_ALG):
+        self.skipTest(f'Algorithm "{alg}" not supported by simulator')
+
     def setUp(self):
         super().setUp()
         try:
@@ -204,6 +216,15 @@ class TSS2_EsapiTest(TSS2_BaseTest):
         self.tcti = self.tpm.get_tcti()
         self.ectx = ESAPI(self.tcti)
 
+        # record the supported algorithms
+        self._supported_algs = []
+        more = True
+        while more:
+            more, data = self.ectx.get_capability(
+                TPM2_CAP.ALGS, 0, lib.TPM2_MAX_CAP_ALGS
+            )
+            self._supported_algs += [x.alg for x in data.data.algorithms]
+
     def tearDown(self):
         self.ectx.close()
         self.tcti.close()
