@@ -324,7 +324,7 @@ class CryptoTest(TSS2_EsapiTest):
         pub.publicArea.type = TPM2_ALG.NULL
 
         with self.assertRaises(ValueError) as e:
-            pem = crypto._public_to_pem(pub.publicArea)
+            crypto._public_to_pem(pub.publicArea)
         self.assertEqual(str(e.exception), f"unsupported key type: {TPM2_ALG.NULL}")
 
     def test_topem_rsa(self):
@@ -454,7 +454,7 @@ class CryptoTest(TSS2_EsapiTest):
         self.assertEqual(key, ekey)
 
         with self.assertRaises(ValueError) as e:
-            key = crypto._kdfa(
+            crypto._kdfa(
                 TPM2_ALG.SHA256,
                 b"key data",
                 b"label data",
@@ -465,7 +465,7 @@ class CryptoTest(TSS2_EsapiTest):
         self.assertEqual(str(e.exception), "bad key length 123, not a multiple of 8")
 
         with self.assertRaises(ValueError) as e:
-            key = crypto._kdfa(
+            crypto._kdfa(
                 TPM2_ALG.LAST + 1,
                 b"key data",
                 b"label data",
@@ -490,7 +490,7 @@ class CryptoTest(TSS2_EsapiTest):
         self.assertEqual(key, ekey)
 
         with self.assertRaises(ValueError) as e:
-            key = crypto.kdfe(
+            crypto.kdfe(
                 TPM2_ALG.SHA256,
                 b"z data",
                 b"use data",
@@ -501,7 +501,7 @@ class CryptoTest(TSS2_EsapiTest):
         self.assertEqual(str(e.exception), "bad key length 123, not a multiple of 8")
 
         with self.assertRaises(ValueError) as e:
-            key = crypto.kdfe(
+            crypto.kdfe(
                 TPM2_ALG.LAST + 1,
                 b"z data",
                 b"use data",
@@ -580,7 +580,7 @@ class CryptoTest(TSS2_EsapiTest):
 
     def test_ecc_bad_curves(self):
         with self.assertRaises(ValueError) as e:
-            pub = TPMT_PUBLIC.from_pem(ecc_bad_curve)
+            TPMT_PUBLIC.from_pem(ecc_bad_curve)
         self.assertEqual(str(e.exception), "unsupported curve: sect163r2")
 
         pub = TPMT_PUBLIC.from_pem(ecc_public_key)
@@ -595,11 +595,11 @@ class CryptoTest(TSS2_EsapiTest):
         der = b64decode(b64)
 
         with self.assertRaises(ValueError) as e:
-            priv = TPMT_SENSITIVE.from_pem(der)
+            TPMT_SENSITIVE.from_pem(der)
         self.assertEqual(str(e.exception), "unsupported key type: _DSAPrivateKey")
 
         with self.assertRaises(ValueError) as e:
-            pub = TPMT_PUBLIC.from_pem(dsa_public_key)
+            TPMT_PUBLIC.from_pem(dsa_public_key)
         self.assertEqual(str(e.exception), "unsupported key type: _DSAPublicKey")
 
     def test_from_pem_with_symmetric(self):
